@@ -18,11 +18,11 @@
 """
 
 
-class JSONConvert(object):
+class JSONConverter(object):
     # This magic number is work around.
     # Body size limitation with PUT method,
     # The boudnary of body size in over 27915 byte and under 27938 byte.
-    maxdata = 100
+    MAXDATA = 100
 
     def __init__(self, domain):
         self.domain = domain
@@ -37,35 +37,35 @@ class JSONConvert(object):
         self.expire = '86400'
         self.ttl = 3600
 
-    def setRecord(self, name, rtype, content, ttl=3600, priority=False):
+    def set_record(self, name, rtype, content, ttl=3600, priority=False):
         line = name + ' ' + rtype + ' ' + content + ' ' + str(ttl)
         if priority:
             line += ' ' + str(priority)
         record = [line]
         return record
 
-    def readRecords(self, listitems):
+    def read_records(self, listitems):
         import re
         for line in listitems:
             # Ignore number(#) at begining of a line.
             # and ignore blank lines.
             if not re.search('^#|^$', line):
-                self.generateRecords(line)
+                self.generate_records(line)
 
-    def generateRecords(self, line):
+    def generate_records(self, line):
         d = {
-            "name": self.checkkey(line, 0),
-            "type": self.checkkey(line, 1),
-            "content": self.checkkey(line, 2),
-            "ttl": int(self.checkkey(line, 3))
+            "name": self.check_key(line, 0),
+            "type": self.check_key(line, 1),
+            "content": self.check_key(line, 2),
+            "ttl": int(self.check_key(line, 3))
             }
-        if self.checkkey(line, 4):
+        if self.check_key(line, 4):
             d.update(
-                {"priority": int(self.checkkey(line, 4))}
+                {"priority": int(self.check_key(line, 4))}
                 )
         self.records.append(d)
 
-    def generateTemplate(self, domain, ipaddr, desc):
+    def generate_template(self, domain, ipaddr, desc):
         from datetime import date
         serial = date.strftime(date.today(), '%Y%m%d') + '01'
         ns = 'ns.' + domain
@@ -90,7 +90,7 @@ class JSONConvert(object):
             }
         return record_d
 
-    def generateZone(self, domain, template, dtype, master=None):
+    def generate_zone(self, domain, template, dtype, master=None):
         # If there is a SOA record in records,
         # add self SOA records.
         self.zone = {
@@ -102,7 +102,7 @@ class JSONConvert(object):
                 ]
             }
 
-    def checkkey(self, key, index):
+    def check_key(self, key, index):
         import re
         length = len(re.split('\s*', key))
         if length > index:
@@ -111,13 +111,13 @@ class JSONConvert(object):
             v = None
         return v
 
-    def genData(self, act):
+    def generata_data(self, act):
         data = lambda act: {"records": self.records} \
             if act else {"name": self.domain, "records": self.records}
         self.dict_records.append(data(act))
         self.records = []
 
-    def separateInputFile(self, file):
+    def separate_input_file(self, file):
         import re
         line_index = 1
         separated_str = ''
@@ -125,7 +125,7 @@ class JSONConvert(object):
             # for test only
             delta = self.delta
         else:
-            delta = self.maxdata
+            delta = self.MAXDATA
 
         for line in file:
             if not re.search('^#|^$', line):
@@ -138,11 +138,7 @@ class JSONConvert(object):
                 separated_str += line
         self.separated_list.append(separated_str)
 
-    def decodeJSON(self, data):
-        import json
-        json.load(data, 'utf-8')
-
-    def getSOA(self, record, content):
+    def get_soa(self, record, content):
         from datetime import date
         new_record = record.copy()
 
